@@ -25,7 +25,7 @@ import multiprocessing
 from io import open
 import re
 
-from glances.compat import ConfigParser, NoOptionError, system_exec
+from glances.compat import ConfigParser, NoOptionError, NoSectionError, system_exec
 from glances.globals import BSD, LINUX, MACOS, SUNOS, WINDOWS
 from glances.logger import logger
 
@@ -91,6 +91,24 @@ def system_config_dir():
     return path
 
 
+def default_config_dir():
+    r"""Return the system-wide config dir (full path).
+
+    - Linux, SunOS, *BSD, macOS: /usr/share/doc (as defined in the setup.py files)
+    - Windows: %APPDATA%\glances
+    """
+    if LINUX or SUNOS or BSD or MACOS:
+        path = '/usr/share/doc'
+    else:
+        path = os.environ.get('APPDATA')
+    if path is None:
+        path = ''
+    else:
+        path = os.path.join(path, 'glances')
+
+    return path
+
+
 class Config(object):
 
     """This class is used to access/read config file, if it exists.
@@ -105,9 +123,13 @@ class Config(object):
         self._loaded_config_file = None
 
         # Re patern for optimize research of `foo`
-        self.re_pattern = re.compile('(\`.+?\`)')
+        self.re_pattern = re.compile(r'(\`.+?\`)')
+
+        try:
+            self.parser = ConfigParser(interpolation=None)
+        except TypeError:
+            self.parser = ConfigParser()
 
-        self.parser = ConfigParser()
         self.read()
 
     def config_file_paths(self):
@@ -125,6 +147,7 @@ class Config(object):
             * /path/to/file (via -C flag)
             * user's home directory (per-user settings)
             * system-wide directory (system-wide settings)
+            * default pip directory (as defined in the setup.py file)
         """
         paths = []
 
@@ -133,13 +156,14 @@ class Config(object):
 
         paths.append(os.path.join(user_config_dir(), self.config_filename))
         paths.append(os.path.join(system_config_dir(), self.config_filename))
+        paths.append(os.path.join(default_config_dir(), self.config_filename))
 
         return paths
 
     def read(self):
         """Read the config file, if it exists. Using defaults otherwise."""
         for config_file in self.config_file_paths():
-            logger.info('Search glances.conf file in {}'.format(config_file))
+            logger.debug('Search glances.conf file in {}'.format(config_file))
             if os.path.exists(config_file):
                 try:
                     with open(config_file, encoding='utf-8') as f:
@@ -153,6 +177,20 @@ class Config(object):
                 self._loaded_config_file = config_file
                 break
 
+        # Set the default values for section not configured
+        self.sections_set_default()
+
+    def sections_set_default(self):
+        # Globals
+        if not self.parser.has_section('global'):
+            self.parser.add_section('global')
+        self.set_default('global', 'strftime_format', '')
+
+        # check_update
+        if not self.parser.has_section('global'):
+            self.parser.add_section('global')
+        self.set_default('global', 'check_update', 'false')
+
         # Quicklook
         if not self.parser.has_section('quicklook'):
             self.parser.add_section('quicklook')
@@ -275,13 +313,13 @@ class Config(object):
         If it did not exist, then return the default value.
 
         It allows user to define dynamic configuration key (see issue#1204)
-        Dynamic vlaue should starts and end with the ` char
+        Dynamic value should starts and end with the ` char
         Example: prefix=`hostname`
         """
         ret = default
         try:
             ret = self.parser.get(section, option)
-        except NoOptionError:
+        except (NoOptionError, NoSectionError):
             pass
 
         # Search a substring `foo` and replace it by the result of its exec
@@ -298,19 +336,19 @@ class Config(object):
         """Get the int value of an option, if it exists."""
         try:
             return self.parser.getint(section, option)
-        except NoOptionError:
+        except (NoOptionError, NoSectionError):
             return int(default)
 
     def get_float_value(self, section, option, default=0.0):
         """Get the float value of an option, if it exists."""
         try:
             return self.parser.getfloat(section, option)
-        except NoOptionError:
+        except (NoOptionError, NoSectionError):
             return float(default)
 
     def get_bool_value(self, section, option, default=True):
         """Get the bool value of an option, if it exists."""
         try:
             return self.parser.getboolean(section, option)
-        except NoOptionError:
+        except (NoOptionError, NoSectionError):
             return bool(default)
