@@ -20,11 +20,12 @@
 """Manage Glances update."""
 
 from datetime import datetime, timedelta
-from distutils.version import LooseVersion
+from packaging.version import Version
 import threading
 import json
 import pickle
 import os
+from ssl import CertificateError
 
 from glances import __version__
 from glances.compat import nativestr, urlopen, HTTPError, URLError
@@ -112,7 +113,7 @@ class Outdated(object):
             return False
 
         logger.debug("Check Glances version (installed: {} / latest: {})".format(self.installed_version(), self.latest_version()))
-        return LooseVersion(self.latest_version()) > LooseVersion(self.installed_version())
+        return Version(self.latest_version()) > Version(self.installed_version())
 
     def _load_cache(self):
         """Load cache file and return cached data"""
@@ -155,7 +156,7 @@ class Outdated(object):
 
         try:
             res = urlopen(PYPI_API_URL, timeout=3).read()
-        except (HTTPError, URLError) as e:
+        except (HTTPError, URLError, CertificateError) as e:
             logger.debug("Cannot get Glances version from the PyPI RESTful API ({})".format(e))
         else:
             self.data[u'latest_version'] = json.loads(nativestr(res))['info']['version']
