@@ -1,6 +1,5 @@
-'use strict';
 
-function GlancesPluginNetworkController($scope, $filter, GlancesStats, ARGUMENTS) {
+export default function GlancesPluginNetworkController($scope, $filter, GlancesStats, ARGUMENTS) {
     var vm = this;
     vm.arguments = ARGUMENTS;
     vm.networks = [];
@@ -19,16 +18,18 @@ function GlancesPluginNetworkController($scope, $filter, GlancesStats, ARGUMENTS
         vm.networks = [];
         for (var i = 0; i < networkStats.length; i++) {
             var networkData = networkStats[i];
+            var alias = networkData['alias'] !== undefined ? networkData['alias'] : null
 
             var network = {
                 'interfaceName': networkData['interface_name'],
+                'ifname': alias ? alias : networkData['interface_name'],
                 'rx': networkData['rx'],
                 'tx': networkData['tx'],
                 'cx': networkData['cx'],
                 'time_since_update': networkData['time_since_update'],
                 'cumulativeRx': networkData['cumulative_rx'],
                 'cumulativeTx': networkData['cumulative_tx'],
-                'cumulativeCx': networkData['cumulative_cx']
+                'cumulativeCx': networkData['cumulative_cx'],
             };
 
             vm.networks.push(network);
