@@ -30,6 +30,11 @@ from glances.plugins.glances_plugin import GlancesPlugin
 import psutil
 
 # Fields description
+# description: human readable description
+# short_name: shortname to use un UI
+# unit: unit type
+# rate: is it a rate ? If yes, // by time_since_update when displayed,
+# min_symbol: Auto unit should be used if value > than 1 'X' (K, M, G)...
 fields_description = {
     'total': {'description': 'Sum of all CPU percentages (except idle).',
               'unit': 'percent'},
@@ -61,12 +66,26 @@ CPU while the hypervisor is servicing another virtual processor.',
 second. A context switch is a procedure that a computer\'s CPU (central \
 processing unit) follows to change from one task (or process) to \
 another while ensuring that the tasks do not conflict.',
-                     'unit': 'percent'},
+                     'unit': 'number',
+                     'rate': True,
+                     'min_symbol': 'K',
+                     'short_name': 'ctx_sw'},
     'interrupts': {'description': 'number of interrupts per second.',
-                   'unit': 'percent'},
+                   'unit': 'number',
+                   'rate': True,
+                   'min_symbol': 'K',
+                   'short_name': 'inter'},
     'soft_interrupts': {'description': 'number of software interrupts per second. Always set to \
 0 on Windows and SunOS.',
-                        'unit': 'percent'},
+                        'unit': 'number',
+                        'rate': True,
+                        'min_symbol': 'K',
+                        'short_name': 'sw_int'},
+    'syscalls': {'description': 'number of system calls per second. Always 0 on Linux OS.',
+                 'unit': 'number',
+                 'rate': True,
+                 'min_symbol': 'K',
+                 'short_name': 'sw_int'},
     'cpucore': {'description': 'Total number of CPU core.',
                 'unit': 'number'},
     'time_since_update': {'description': 'Number of seconds since last update.',
@@ -265,15 +284,15 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist and plugin not disable
-        if not self.stats or self.args.percpu or self.is_disable():
+        if not self.stats or self.args.percpu or self.is_disabled():
             return ret
 
-        # Build the string message
         # If user stat is not here, display only idle / total CPU usage (for
         # exemple on Windows OS)
         idle_tag = 'user' not in self.stats
 
-        # Header
+        # First line
+        # Total + (idle) + ctx_sw
         msg = '{}'.format('CPU')
         ret.append(self.curse_add_line(msg, "TITLE"))
         trend_user = self.get_trend('user')
@@ -291,101 +310,50 @@ class Plugin(GlancesPlugin):
         # Idle CPU
         if 'idle' in self.stats and not idle_tag:
             msg = '  {:8}'.format('idle:')
-            ret.append(self.curse_add_line(msg))
+            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle',
+                                                                        option='optional')))
             msg = '{:5.1f}%'.format(self.stats['idle'])
-            ret.append(self.curse_add_line(msg))
+            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle',
+                                                                        option='optional')))
         # ctx_switches
-        if 'ctx_switches' in self.stats:
-            msg = '  {:8}'.format('ctx_sw:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='ctx_switches', option='optional')))
-            msg = '{:>5}'.format(self.auto_unit(int(self.stats['ctx_switches'] // self.stats['time_since_update']),
-                                                min_symbol='K'))
-            ret.append(self.curse_add_line(
-                msg, self.get_views(key='ctx_switches', option='decoration'),
-                optional=self.get_views(key='ctx_switches', option='optional')))
+        ret.extend(self.curse_add_stat('ctx_switches', width=15, header='  '))
 
-        # New line
+        # Second line
+        # user|idle + irq + interrupts
         ret.append(self.curse_new_line())
         # User CPU
-        if 'user' in self.stats:
-            msg = '{:8}'.format('user:')
-            ret.append(self.curse_add_line(msg))
-            msg = '{:5.1f}%'.format(self.stats['user'])
-            ret.append(self.curse_add_line(
-                msg, self.get_views(key='user', option='decoration')))
+        if not idle_tag:
+            ret.extend(self.curse_add_stat('user', width=15))
         elif 'idle' in self.stats:
-            msg = '{:8}'.format('idle:')
-            ret.append(self.curse_add_line(msg))
-            msg = '{:5.1f}%'.format(self.stats['idle'])
-            ret.append(self.curse_add_line(msg))
+            ret.extend(self.curse_add_stat('idle', width=15))
         # IRQ CPU
-        if 'irq' in self.stats:
-            msg = '  {:8}'.format('irq:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='irq', option='optional')))
-            msg = '{:5.1f}%'.format(self.stats['irq'])
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='irq', option='optional')))
+        ret.extend(self.curse_add_stat('irq', width=15, header='  '))
         # interrupts
-        if 'interrupts' in self.stats:
-            msg = '  {:8}'.format('inter:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='interrupts', option='optional')))
-            msg = '{:>5}'.format(int(self.stats['interrupts'] // self.stats['time_since_update']))
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='interrupts', option='optional')))
+        ret.extend(self.curse_add_stat('interrupts', width=15, header='  '))
 
-        # New line
+        # Third line
+        # system|core + nice + sw_int
         ret.append(self.curse_new_line())
         # System CPU
-        if 'system' in self.stats and not idle_tag:
-            msg = '{:8}'.format('system:')
-            ret.append(self.curse_add_line(msg))
-            msg = '{:5.1f}%'.format(self.stats['system'])
-            ret.append(self.curse_add_line(
-                msg, self.get_views(key='system', option='decoration')))
+        if not idle_tag:
+            ret.extend(self.curse_add_stat('system', width=15))
         else:
-            msg = '{:8}'.format('core:')
-            ret.append(self.curse_add_line(msg))
-            msg = '{:>6}'.format(self.stats['nb_log_core'])
-            ret.append(self.curse_add_line(msg))
+            ret.extend(self.curse_add_stat('core', width=15))
         # Nice CPU
-        if 'nice' in self.stats:
-            msg = '  {:8}'.format('nice:')
-            ret.append(self.curse_add_line(
-                msg, optional=self.get_views(key='nice', option='optional')))
-            msg = '{:5.1f}%'.format(self.stats['nice'])
-            ret.append(self.curse_add_line(
-                msg, optional=self.get_views(key='nice', option='optional')))
+        ret.extend(self.curse_add_stat('nice', width=15, header='  '))
         # soft_interrupts
-        if 'soft_interrupts' in self.stats:
-            msg = '  {:8}'.format('sw_int:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='soft_interrupts', option='optional')))
-            msg = '{:>5}'.format(int(self.stats['soft_interrupts'] // self.stats['time_since_update']))
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='soft_interrupts', option='optional')))
+        ret.extend(self.curse_add_stat('soft_interrupts', width=15, header='  '))
 
-        # New line
+        # Fourth line
+        # iowat + steal + syscalls
         ret.append(self.curse_new_line())
         # IOWait CPU
-        if 'iowait' in self.stats:
-            msg = '{:8}'.format('iowait:')
-            ret.append(self.curse_add_line(
-                msg, optional=self.get_views(key='iowait', option='optional')))
-            msg = '{:5.1f}%'.format(self.stats['iowait'])
-            ret.append(self.curse_add_line(
-                msg, self.get_views(key='iowait', option='decoration'),
-                optional=self.get_views(key='iowait', option='optional')))
+        ret.extend(self.curse_add_stat('iowait', width=15))
         # Steal CPU usage
-        if 'steal' in self.stats:
-            msg = '  {:8}'.format('steal:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='steal', option='optional')))
-            msg = '{:5.1f}%'.format(self.stats['steal'])
-            ret.append(self.curse_add_line(
-                msg, self.get_views(key='steal', option='decoration'),
-                optional=self.get_views(key='steal', option='optional')))
-        # syscalls
+        ret.extend(self.curse_add_stat('steal', width=15, header='  '))
         # syscalls: number of system calls since boot. Always set to 0 on Linux. (do not display)
-        if 'syscalls' in self.stats and not LINUX:
-            msg = '  {:8}'.format('syscal:')
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='syscalls', option='optional')))
-            msg = '{:>5}'.format(int(self.stats['syscalls'] // self.stats['time_since_update']))
-            ret.append(self.curse_add_line(msg, optional=self.get_views(key='syscalls', option='optional')))
+        if not LINUX:
+            ret.extend(self.curse_add_stat('syscalls', width=15, header='  '))
 
         # Return the message with decoration
         return ret
