@@ -37,6 +37,26 @@ from glances.thresholds import glances_thresholds
 from glances.timer import Counter, Timer
 
 
+fields_unit_short = {
+    'percent': '%'
+}
+
+fields_unit_type = {
+    'percent': 'float',
+    'percents': 'float',
+    'number': 'int',
+    'numbers': 'int',
+    'int': 'int',
+    'ints': 'int',
+    'float': 'float',
+    'floats': 'float',
+    'second': 'int',
+    'seconds': 'int',
+    'byte': 'int',
+    'bytes': 'int'
+}
+
+
 class GlancesPlugin(object):
     """Main class for Glances plugin."""
 
@@ -143,7 +163,7 @@ class GlancesPlugin(object):
         """Return the key of the list."""
         return None
 
-    def is_enable(self, plugin_name=None):
+    def is_enabled(self, plugin_name=None):
         """Return true if plugin is enabled."""
         if not plugin_name:
             plugin_name = self.plugin_name
@@ -153,9 +173,9 @@ class GlancesPlugin(object):
             d = getattr(self.args, 'enable_' + plugin_name, True)
         return d is False
 
-    def is_disable(self, plugin_name=None):
+    def is_disabled(self, plugin_name=None):
         """Return true if plugin is disabled."""
-        return not self.is_enable(plugin_name=plugin_name)
+        return not self.is_enabled(plugin_name=plugin_name)
 
     def _json_dumps(self, d):
         """Return the object 'd' in a JSON format.
@@ -169,8 +189,8 @@ class GlancesPlugin(object):
 
     def history_enable(self):
         return self.args is not None and \
-               not self.args.disable_history and \
-               self.get_items_history_list() is not None
+            not self.args.disable_history and \
+            self.get_items_history_list() is not None
 
     def init_stats_history(self):
         """Init the stats history (dict of GlancesAttribute)."""
@@ -326,7 +346,6 @@ class GlancesPlugin(object):
                 re.split(r"(\d+|\D+)", self.has_alias(stat[key]) or stat[key])
             )))
 
-
     @short_system_name.setter
     def short_system_name(self, short_name):
         """Set the short detected OS name (SNMP)."""
@@ -960,6 +979,93 @@ class GlancesPlugin(object):
         """Go to a new line."""
         return self.curse_add_line('\n')
 
+    def curse_add_stat(self, key, width=None,
+                       header='', separator='', trailer=''):
+        """Return a list of dict messages with the 'key: value' result
+
+          <=== width ===>
+        __key     : 80.5%__
+        | |       | |    |_ trailer
+        | |       | |_ self.stats[key]
+        | |       |_ separator
+        | |_ key
+        |_ trailer
+
+        Instead of:
+            msg = '  {:8}'.format('idle:')
+            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle', option='optional')))
+            msg = '{:5.1f}%'.format(self.stats['idle'])
+            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle', option='optional')))
+
+        Use:
+            ret.extend(self.curse_add_stat('idle', width=15, header='  '))
+
+        """
+        if key not in self.stats:
+            return []
+
+        # Check if a shortname is defined
+        if key in self.fields_description and \
+           'short_name' in self.fields_description[key]:
+            key_name = self.fields_description[key]['short_name']
+        else:
+            key_name = key
+
+        # Check if unit is defined and get the short unit char in the unit_sort dict
+        if key in self.fields_description and \
+           'unit' in self.fields_description[key] and \
+           self.fields_description[key]['unit'] in fields_unit_short:
+            # Get the shortname
+            unit_short = fields_unit_short[self.fields_description[key]['unit']]
+        else:
+            unit_short = ''
+
+        # Check if unit is defined and get the unit type unit_type dict
+        if key in self.fields_description and \
+           'unit' in self.fields_description[key] and \
+           self.fields_description[key]['unit'] in fields_unit_type:
+            # Get the shortname
+            unit_type = fields_unit_type[self.fields_description[key]['unit']]
+        else:
+            unit_type = 'float'
+
+        # Is it a rate ? Yes, compute it thanks to the time_since_update key
+        if key in self.fields_description and \
+           'rate' in self.fields_description[key] and \
+           self.fields_description[key]['rate'] is True:
+            value = self.stats[key] // self.stats['time_since_update']
+        else:
+            value = self.stats[key]
+
+        if width is None:
+            msg_item = header + '{}'.format(key_name) + separator
+            if unit_type == 'float':
+                msg_value = '{:.1f}{}'.format(value, unit_short) + trailer
+            elif 'min_symbol' in self.fields_description[key]:
+                msg_value = '{}{}'.format(self.auto_unit(int(value),
+                                                         min_symbol=self.fields_description[key]['min_symbol']),
+                                          unit_short) + trailer
+            else:
+                msg_value = '{}{}'.format(int(value), unit_short) + trailer
+        else:
+            # Define the size of the message
+            # item will be on the left
+            # value will be on the right
+            msg_item = header + '{:{width}}'.format(key_name, width=width-7) + separator
+            if unit_type == 'float':
+                msg_value = '{:5.1f}{}'.format(value, unit_short) + trailer
+            elif 'min_symbol' in self.fields_description[key]:
+                msg_value = '{:>5}{}'.format(self.auto_unit(int(value),
+                                                            min_symbol=self.fields_description[key]['min_symbol']),
+                                             unit_short) + trailer
+            else:
+                msg_value = '{:>5}{}'.format(int(value), unit_short) + trailer
+        decoration = self.get_views(key=key, option='decoration')
+        optional = self.get_views(key=key, option='optional')
+
+        return [self.curse_add_line(msg_item, optional=optional),
+                self.curse_add_line(msg_value, decoration=decoration, optional=optional)]
+
     @property
     def align(self):
         """Get the curse align."""
@@ -1045,8 +1151,9 @@ class GlancesPlugin(object):
         - if the plugin is enabled.
         - if the refresh_timer is finished
         """
+
         def wrapper(self, *args, **kw):
-            if self.is_enable() and (self.refresh_timer.finished() or self.stats == self.get_init_value):
+            if self.is_enabled() and (self.refresh_timer.finished() or self.stats == self.get_init_value):
                 # Run the method
                 ret = fct(self, *args, **kw)
                 # Reset the timer
