@@ -24,6 +24,7 @@ import platform
 import re
 from io import open
 
+from glances.logger import logger
 from glances.compat import iteritems
 from glances.plugins.glances_plugin import GlancesPlugin
 
@@ -90,6 +91,10 @@ class Plugin(GlancesPlugin):
         # We want to display the stat in the curse interface
         self.display_curse = True
 
+        # Set default rate to 60 seconds
+        if self.get_refresh():
+            self.set_refresh(60)
+
     @GlancesPlugin._check_decorator
     @GlancesPlugin._log_result_decorator
     def update(self):
