@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -19,74 +19,71 @@
 
 """Uptime plugin."""
 
-# Import system libs
 from datetime import datetime, timedelta
 
-# Import psutil
-import psutil
-
-# Import Glances libs
 from glances.plugins.glances_plugin import GlancesPlugin
 
+import psutil
+
 # SNMP OID
 snmp_oid = {'_uptime': '1.3.6.1.2.1.1.3.0'}
 
 
 class Plugin(GlancesPlugin):
-
-    """Glances' uptime plugin.
+    """Glances uptime plugin.
 
     stats is date (string)
     """
 
-    def __init__(self, args=None):
+    def __init__(self, args=None, config=None):
         """Init the plugin."""
-        GlancesPlugin.__init__(self, args=args)
+        super(Plugin, self).__init__(args=args, config=config)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
 
         # Set the message position
-        self.set_align('right')
+        self.align = 'right'
 
         # Init the stats
-        self.reset()
+        self.uptime = datetime.now() - datetime.fromtimestamp(psutil.boot_time())
 
-    def reset(self):
-        """Reset/init the stats."""
-        self.stats = {}
+    def get_export(self):
+        """Overwrite the default export method.
 
+        Export uptime in seconds.
+        """
+        # Convert the delta time to seconds (with cast)
+        # Correct issue #1092 (thanks to @IanTAtWork)
+        return {'seconds': int(self.uptime.total_seconds())}
+
+    @GlancesPlugin._check_decorator
+    @GlancesPlugin._log_result_decorator
     def update(self):
         """Update uptime stat using the input method."""
-        # Reset stats
-        self.reset()
+        # Init new stats
+        stats = self.get_init_value()
 
-        if self.get_input() == 'local':
+        if self.input_method == 'local':
             # Update stats using the standard system lib
-            uptime = datetime.now() - \
-                datetime.fromtimestamp(psutil.boot_time())
+            self.uptime = datetime.now() - datetime.fromtimestamp(psutil.boot_time())
 
             # Convert uptime to string (because datetime is not JSONifi)
-            self.stats = str(uptime).split('.')[0]
-        elif self.get_input() == 'snmp':
+            stats = str(self.uptime).split('.')[0]
+        elif self.input_method == 'snmp':
             # Update stats using SNMP
-            uptime = self.set_stats_snmp(snmp_oid=snmp_oid)['_uptime']
+            uptime = self.get_stats_snmp(snmp_oid=snmp_oid)['_uptime']
             try:
                 # In hundredths of seconds
-                self.stats = str(timedelta(seconds=int(uptime) / 100))
+                stats = str(timedelta(seconds=int(uptime) / 100))
             except Exception:
                 pass
 
-        # Return the result
+        # Update the stats
+        self.stats = stats
+
         return self.stats
 
-    def msg_curse(self, args=None):
+    def msg_curse(self, args=None, max_width=None):
         """Return the string to display in the curse interface."""
-        # Init the return message
-        ret = []
-
-        # Add the line with decoration
-        ret.append(self.curse_add_line(_("Uptime: {0}").format(self.stats)))
-
-        # Return the message with decoration
-        return ret
+        return [self.curse_add_line('Uptime: {}'.format(self.stats))]
