@@ -29,6 +29,8 @@ from glances.stats import GlancesStats
 from glances.outputs.glances_curses import GlancesCursesStandalone
 from glances.outputs.glances_stdout import GlancesStdout
 from glances.outputs.glances_stdout_csv import GlancesStdoutCsv
+from glances.outputs.glances_stdout_issue import GlancesStdoutIssue
+from glances.outputs.glances_stdout_apidoc import GlancesStdoutApiDoc
 from glances.outdated import Outdated
 from glances.timer import Counter
 
@@ -82,12 +84,20 @@ class GlancesStandalone(object):
             logger.info("Quiet mode is ON, nothing will be displayed")
             # In quiet mode, nothing is displayed
             glances_processes.max_processes = 0
+        elif args.stdout_issue:
+            logger.info("Issue mode is ON")
+            # Init screen
+            self.screen = GlancesStdoutIssue(config=config, args=args)
+        elif args.stdout_apidoc:
+            logger.info("Fields descriptions mode is ON")
+            # Init screen
+            self.screen = GlancesStdoutApiDoc(config=config, args=args)
         elif args.stdout:
             logger.info("Stdout mode is ON, following stats will be displayed: {}".format(args.stdout))
             # Init screen
             self.screen = GlancesStdout(config=config, args=args)
         elif args.stdout_csv:
-            logger.info("Stdout CSV mode is ON, following stats will be displayed: {}".format(args.stdout))
+            logger.info("Stdout CSV mode is ON, following stats will be displayed: {}".format(args.stdout_csv))
             # Init screen
             self.screen = GlancesStdoutCsv(config=config, args=args)
         else:
@@ -111,20 +121,27 @@ class GlancesStandalone(object):
         print("Exporters list: {}".format(
             ', '.join(sorted(self.stats.getExportsList(enable=False)))))
 
-    def __serve_forever(self):
+    def serve_issue(self):
+        """Special mode for the --issue option
+        Update is done in the sceen.update function
+        """
+        ret = not self.screen.update(self.stats)
+        self.end()
+        return ret
+
+    def __serve_once(self):
         """Main loop for the CLI.
 
         return True if we should continue (no exit key has been pressed)
         """
-        # Start a counter used to compute the time needed for
-        # update and export the stats
-        counter = Counter()
-
         # Update stats
+        # Start a counter used to compute the time needed
+        counter = Counter()
         self.stats.update()
         logger.debug('Stats updated duration: {} seconds'.format(counter.get()))
 
         # Export stats
+        # Start a counter used to compute the time needed
         counter_export = Counter()
         self.stats.export(self.stats)
         logger.debug('Stats exported duration: {} seconds'.format(counter_export.get()))
@@ -138,7 +155,8 @@ class GlancesStandalone(object):
         if not self.quiet:
             # The update function return True if an exit key 'q' or 'ESC'
             # has been pressed.
-            ret = not self.screen.update(self.stats, duration=adapted_refresh)
+            ret = not self.screen.update(self.stats,
+                                         duration=adapted_refresh)
         else:
             # Nothing is displayed
             # Break should be done via a signal (CTRL-C)
@@ -149,9 +167,11 @@ class GlancesStandalone(object):
 
     def serve_forever(self):
         """Wrapper to the serve_forever function."""
-        loop = True
-        while loop:
-            loop = self.__serve_forever()
+        # loop = True
+        # while loop:
+        #     loop = self.__serve_once()
+        while self.__serve_once():
+            pass
         self.end()
 
     def end(self):
